@@ -208,7 +208,14 @@ def _api_compare_list(
 
 
 def _api_compare_summary(
-    baseline_commit_id, contender_commit_id, baseline_id, contender_id
+    baseline_commit_id,
+    contender_commit_id,
+    baseline_id,
+    baseline_name,
+    baseline_timestamp,
+    contender_id,
+    contender_name,
+    contender_timestamp,
 ):
     return {
         "commits": {
@@ -245,11 +252,17 @@ def _api_compare_summary(
                 "baseline": {
                     "machine_name": "diana",
                     "run": f"http://localhost/api/runs/{baseline_id}/",
+                    "run_id": baseline_id,
+                    "run_name": baseline_name,
+                    "run_timestamp": baseline_timestamp,
                 },
                 "compare": f"http://localhost/api/compare/runs/{baseline_id}...{contender_id}/",
                 "contender": {
                     "machine_name": "diana",
                     "run": f"http://localhost/api/runs/{contender_id}/",
+                    "run_id": contender_id,
+                    "run_name": contender_name,
+                    "run_timestamp": contender_timestamp,
                 },
             },
         ],
@@ -293,7 +306,7 @@ def _api_history_entity(benchmark_id, case_id, context_id, run_name):
     }
 
 
-def _api_machine_entity(machine_id, links=True):
+def _api_machine_entity(machine_id, machine_name, links=True):
     result = {
         "id": machine_id,
         "architecture_name": "x86_64",
@@ -307,7 +320,7 @@ def _api_machine_entity(machine_id, links=True):
         "cpu_thread_count": 4,
         "kernel_name": "19.6.0",
         "memory_bytes": 17179869184,
-        "name": "diana",
+        "name": machine_name,
         "os_name": "macOS",
         "os_version": "10.15.7",
         "gpu_count": 2,
@@ -323,14 +336,22 @@ def _api_machine_entity(machine_id, links=True):
 
 
 def _api_run_entity(
-    run_id, run_name, commit_id, parent_id, machine_id, now, baseline_id
+    run_id,
+    run_name,
+    commit_id,
+    parent_id,
+    machine_id,
+    machine_name,
+    now,
+    baseline_id,
+    include_baseline=True,
 ):
     result = {
         "id": run_id,
         "name": run_name,
         "timestamp": now,
         "commit": _api_commit_entity(commit_id, parent_id, links=False),
-        "machine": _api_machine_entity(machine_id, links=False),
+        "machine": _api_machine_entity(machine_id, machine_name, links=False),
         "links": {
             "list": "http://localhost/api/runs/",
             "self": "http://localhost/api/runs/%s/" % run_id,
@@ -338,8 +359,10 @@ def _api_run_entity(
             "machine": "http://localhost/api/machines/%s/" % machine_id,
         },
     }
+    baseline_url = None
     if baseline_id:
         baseline_url = "http://localhost/api/runs/%s/" % baseline_id
+    if include_baseline:
         result["links"]["baseline"] = baseline_url
     return result
 
@@ -404,7 +427,11 @@ COMPARE_SUMMARY = _api_compare_summary(
     "some-baseline-commit-id",
     "some-contender-commit-id",
     "some-baseline-run-id",
+    "commit: 4beb514d071c9beec69b8917b5265e77ade22fb3",
+    "2021-02-24T23:12:11",
     "some-contender-run-id",
+    "commit: 02addad336ba19a654f9c857ede546331be7b631",
+    "2021-02-25T06:02:51",
 )
 CONTEXT_ENTITY = _api_context_entity("some-context-uuid-1")
 HISTORY_ENTITY = _api_history_entity(
@@ -413,13 +440,14 @@ HISTORY_ENTITY = _api_history_entity(
     "some-context-uuid-1",
     "some run name",
 )
-MACHINE_ENTITY = _api_machine_entity("some-machine-uuid-1")
+MACHINE_ENTITY = _api_machine_entity("some-machine-uuid-1", "some-machine-name")
 RUN_ENTITY = _api_run_entity(
     "some-run-uuid-1",
     "some run name",
     "some-commit-uuid-1",
     "some-parent-commit-uuid-1",
     "some-machine-uuid-1",
+    "some-machine-name",
     "2021-02-04T17:22:05.225583",
     "some-run-uuid-0",
 )
@@ -430,8 +458,10 @@ RUN_LIST = [
         "some-commit-uuid-1",
         "some-parent-commit-uuid-1",
         "some-machine-uuid-1",
+        "some-machine-name",
         "2021-02-04T17:22:05.225583",
         None,
+        include_baseline=False,
     ),
 ]
 USER_ENTITY = _api_user_entity(FakeUser1())
