@@ -455,11 +455,17 @@
                                     "baseline": {
                                         "machine_name": "diana",
                                         "run": "http://localhost/api/runs/some-baseline-run-id/",
+                                        "run_id": "some-baseline-run-id",
+                                        "run_name": "commit: 4beb514d071c9beec69b8917b5265e77ade22fb3",
+                                        "run_timestamp": "2021-02-24T23:12:11",
                                     },
                                     "compare": "http://localhost/api/compare/runs/some-baseline-run-id...some-contender-run-id/",
                                     "contender": {
                                         "machine_name": "diana",
                                         "run": "http://localhost/api/runs/some-contender-run-id/",
+                                        "run_id": "some-contender-run-id",
+                                        "run_name": "commit: 02addad336ba19a654f9c857ede546331be7b631",
+                                        "run_timestamp": "2021-02-25T06:02:51",
                                     },
                                 }
                             ],
@@ -578,7 +584,7 @@
                                 "self": "http://localhost/api/machines/some-machine-uuid-1/",
                             },
                             "memory_bytes": 17179869184,
-                            "name": "diana",
+                            "name": "some-machine-name",
                             "os_name": "macOS",
                             "os_version": "10.15.7",
                         }
@@ -612,7 +618,7 @@
                                     "self": "http://localhost/api/machines/some-machine-uuid-1/",
                                 },
                                 "memory_bytes": 17179869184,
-                                "name": "diana",
+                                "name": "some-machine-name",
                                 "os_name": "macOS",
                                 "os_version": "10.15.7",
                             }
@@ -675,7 +681,7 @@
                                 "id": "some-machine-uuid-1",
                                 "kernel_name": "19.6.0",
                                 "memory_bytes": 17179869184,
-                                "name": "diana",
+                                "name": "some-machine-name",
                                 "os_name": "macOS",
                                 "os_version": "10.15.7",
                             },
@@ -728,7 +734,7 @@
                                     "id": "some-machine-uuid-1",
                                     "kernel_name": "19.6.0",
                                     "memory_bytes": 17179869184,
-                                    "name": "diana",
+                                    "name": "some-machine-name",
                                     "os_name": "macOS",
                                     "os_version": "10.15.7",
                                 },
@@ -1137,14 +1143,14 @@
                 "tags": ["Comparisons"],
             }
         },
-        "/api/compare/commits/{compare_ids}/": {
+        "/api/compare/commits/{compare_shas}/": {
             "get": {
                 "description": "Compare benchmark results.",
                 "parameters": [
                     {
                         "example": "<baseline_sha>...<contender_sha>",
                         "in": "path",
-                        "name": "compare_ids",
+                        "name": "compare_shas",
                         "required": True,
                         "schema": {"type": "string"},
                     }
